@@ -1,7 +1,7 @@
 ### Example of Section 4
 
-library(mclust)
-library(cluster)
+library("mclust")
+library("cluster")
 
 p <- 4
 K <- 6
@@ -33,9 +33,12 @@ for (bo in omega){
 		Q <- MixSim(BarOmega = bo, K = K, p = p)
 		A <- simdataset(n = n, Pi = Q$Pi, Mu = Q$Mu, S = Q$S)
 
+		# Use try(...) to catch Mclust failure instances
 		id.Mclust <- try(Mclust(A$X, G = K, model = "VVV")$class)
+		# Provide error ids if a failure occurs
 		if (inherits(id.Mclust, what = "try-error") || (is.null(id.Mclust)))
 			id.Mclust <- rep(1, n)
+
 		id.Kmeans <- kmeans(A$X, K, iter.max = 1000, nstart = 10)$cluster
 		id.PAM <- pam(A$X, K)$clustering
 		d <- dist(A$X, method = "euclidean")
@@ -58,23 +61,5 @@ for (bo in omega){
 
 	}
 
-	cat("Omega =", bo, "\n\n")
-
-	cat("Mclust: AR mean =", mean(AR.Mclust), " sd =", sd(AR.Mclust), "\n")
-	cat("Mclust: P mean =", mean(P.Mclust), " sd =", sd(P.Mclust), "\n")
-	cat("Mclust: VI mean =", mean(VI.Mclust), " sd =", sd(VI.Mclust), "\n\n")
-
-	cat("Kmeans: AR mean =", mean(AR.Kmeans), " sd =", sd(AR.Kmeans), "\n")
-	cat("Kmeans: P mean =", mean(P.Kmeans), " sd =", sd(P.Kmeans), "\n")
-	cat("Kmeans: VI mean =", mean(VI.Kmeans), " sd =", sd(VI.Kmeans), "\n\n")
-
-	cat("PAM: AR mean =", mean(AR.PAM), " sd =", sd(AR.PAM), "\n")
-	cat("PAM: P mean =", mean(P.PAM), " sd =", sd(P.PAM), "\n")
-	cat("PAM: VI mean =", mean(VI.PAM), " sd =", sd(VI.PAM), "\n\n")
-
-	cat("Ward: AR mean =", mean(AR.Ward), " sd =", sd(AR.Ward), "\n")
-	cat("Ward: P mean =", mean(P.Ward), " sd =", sd(P.Ward), "\n")
-	cat("Ward: VI mean =", mean(VI.Ward), " sd =", sd(VI.Ward), "\n\n")
-
 }
 
